OperatorBuilder

Struct OperatorBuilder 

pub struct OperatorBuilder;
Builder for creating stream operators

Implementations

Source

impl OperatorBuilder

pub fn map<In, Out, F>(func: F) -> MapOperator<In, Out, F>
where F: Fn(In) -> Out + Send + Sync,

Create a new map operator

pub fn filter<T, F>(predicate: F) -> FilterOperator<T, F>
where F: Fn(&T) -> bool + Send + Sync,

Create a new filter operator

pub fn window_reduce<T, F>( func: F, window: WindowConfig, ) -> WindowReduceOperator<T, F>
where F: Fn(T, T) -> T + Send + Sync, T: Clone,

Create a new window reduce operator

pub fn sum_window<T>( window: WindowConfig, ) -> WindowReduceOperator<T, impl Fn(T, T) -> T>
where T: Add<Output = T> + Clone + Send,

Helper to create a sum operator with a window

pub fn count_window( window: WindowConfig, ) -> WindowReduceOperator<usize, impl Fn(usize, usize) -> usize>

Helper to create a count operator with a window

pub fn avg_window<T>( window: WindowConfig, ) -> WindowReduceOperator<(T, usize), Box<dyn Fn((T, usize), (T, usize)) -> (T, usize) + Send + Sync>>
where T: Add<Output = T> + Clone + Send + 'static,

Helper to create an average operator with a window