pub struct OperatorBuilder;Expand description
Builder for creating stream operators
Implementations
Sourceimpl OperatorBuilder
impl OperatorBuilder
Sourcepub fn map<In, Out, F>(func: F) -> MapOperator<In, Out, F>
pub fn map<In, Out, F>(func: F) -> MapOperator<In, Out, F>
Create a new map operator
Sourcepub fn filter<T, F>(predicate: F) -> FilterOperator<T, F>
pub fn filter<T, F>(predicate: F) -> FilterOperator<T, F>
Create a new filter operator
Sourcepub fn window_reduce<T, F>(
func: F,
window: WindowConfig,
) -> WindowReduceOperator<T, F>
pub fn window_reduce<T, F>( func: F, window: WindowConfig, ) -> WindowReduceOperator<T, F>
Create a new window reduce operator
Sourcepub fn sum_window<T>(
window: WindowConfig,
) -> WindowReduceOperator<T, impl Fn(T, T) -> T>
pub fn sum_window<T>( window: WindowConfig, ) -> WindowReduceOperator<T, impl Fn(T, T) -> T>
Helper to create a sum operator with a window
Sourcepub fn count_window(
window: WindowConfig,
) -> WindowReduceOperator<usize, impl Fn(usize, usize) -> usize>
pub fn count_window( window: WindowConfig, ) -> WindowReduceOperator<usize, impl Fn(usize, usize) -> usize>
Helper to create a count operator with a window
Sourcepub fn avg_window<T>(
window: WindowConfig,
) -> WindowReduceOperator<(T, usize), Box<dyn Fn((T, usize), (T, usize)) -> (T, usize) + Send + Sync>>
pub fn avg_window<T>( window: WindowConfig, ) -> WindowReduceOperator<(T, usize), Box<dyn Fn((T, usize), (T, usize)) -> (T, usize) + Send + Sync>>
Helper to create an average operator with a window